[llvm-commits] CVS: llvm/include/llvm/Target/MRegisterInfo.h

Evan Cheng evan.cheng at apple.com
Tue May 1 01:58:45 PDT 2007



Changes in directory llvm/include/llvm/Target:

MRegisterInfo.h updated: 1.109 -> 1.110
---
Log message:

Add SPAdj parameter to account for call frame setup SP adjustment.

---
Diffs of the changes:  (+4 -3)

 MRegisterInfo.h |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)


Index: llvm/include/llvm/Target/MRegisterInfo.h
diff -u llvm/include/llvm/Target/MRegisterInfo.h:1.109 llvm/include/llvm/Target/MRegisterInfo.h:1.110
--- llvm/include/llvm/Target/MRegisterInfo.h:1.109	Tue May  1 00:57:02 2007
+++ llvm/include/llvm/Target/MRegisterInfo.h	Tue May  1 03:58:27 2007
@@ -512,11 +512,12 @@
   /// referenced by the iterator contains an MO_FrameIndex operand which must be
   /// eliminated by this method.  This method may modify or replace the
   /// specified instruction, as long as it keeps the iterator pointing the the
   /// finished product. The return value is the number of instructions
   /// added to (negative if removed from) the basic block.
   ///
   virtual void eliminateFrameIndex(MachineBasicBlock::iterator MI,
-                                   RegScavenger *RS = NULL) const = 0;
+                                   int SPAdj, RegScavenger *RS=NULL) const = 0;
 
   /// emitProlog/emitEpilog - These methods insert prolog and epilog code into
   /// the function. The return value is the number of instructions
@@ -512,11 +512,12 @@
   /// eliminated by this method.  This method may modify or replace the
   /// specified instruction, as long as it keeps the iterator pointing the the
-  /// finished product. The return value is the number of instructions
-  /// added to (negative if removed from) the basic block.
+  /// finished product. SPAdj is the SP adjustment due to call frame setup
+  /// instruction. The return value is the number of instructions added to
+  /// (negative if removed from) the basic block.
   ///
   virtual void eliminateFrameIndex(MachineBasicBlock::iterator MI,






More information about the llvm-commits mailing list